==> nextcloud-app-mail-1.1.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/bg.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Поща",
    "Auto detect failed. Please use manual mode." : "Неуспешни автоматични настройки. Моля, използвай ръчен режим.",
    "Creating account failed: " : "Неуспешно създаване на профил:",
    "Auto" : "Автоматично",
    "Name" : "Име",
    "Mail Address" : "Имейл адрес",
    "Password" : "Парола",
    "Manual" : "Ръчно",
    "IMAP Settings" : "IMAP настройки",
    "IMAP Host" : "IMAP сървър",
    "IMAP Security" : "IMAP сигурност",
    "None" : "Няма",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP порт",
    "IMAP User" : "IMAP потребител",
    "IMAP Password" : "IMAP парола",
    "SMTP Settings" : "SMTP настройки",
    "SMTP Host" : "SMTP сървър",
    "SMTP Security" : "SMTP сигурност",
    "SMTP Port" : "SMTP порт",
    "SMTP User" : "SMTP потребител",
    "SMTP Password" : "SMTP парола",
    "Save" : "Запис",
    "Connect" : "Свържи",
    "Add mail account" : "Добавяне на профил",
    "Keyboard shortcuts" : "Бързи клавиши",
    "From" : "От",
    "Select account" : "Избери профил",
    "To" : "До",
    "Contact or email address …" : "Контакт или имейл адрес...",
    "Subject" : "Тема",
    "Subject …" : "Тема...",
    "Draft saved" : "Черновата записана",
    "Upload attachment" : "Качи прикачен файл/ове",
    "Add attachment from Files" : "Прикачи от \"Файлове\"",
    "Enable formatting" : "Форматиран текст",
    "Sending …" : "Изпращане...",
    "Go back" : "Назад",
    "Retry" : "Опитай отново",
    "Message sent!" : "Съобщението е изпратено!",
    "Send" : "Изпрати",
    "Uploading {percent}% …" : "Качване {percent}% …",
    "Choose a file to add as attachment" : "Избери файл за прикачване",
    "Plain text" : "Обикновен текст",
    "Rich text" : "Форматиран текст",
    "No messages in this folder" : "Няма съобщения",
    "Draft: " : "Чернова: ",
    "Mark read" : "Маркирай като прочетено",
    "Mark unread" : "Маркирай като непрочетено",
    "Delete" : "Изтриване",
    "Loading messages" : "Зареждане на съобщенията",
    "Reply" : "Отговори",
    "Forward" : "Напред",
    "Could not load your message" : "Вашето съобщение не може да бъде заредено",
    "Download attachment" : "Изтегли прикачените файлове",
    "Save to Files" : "Запази във Файлове",
    "Choose a folder to store the attachment in" : "Избери папка, където да бъде запазен прикаченият файл",
    "New message" : "Ново съобщение",
    "Settings" : "Настройки",
    "Edit account" : "Редактиране на профила",
    "Add folder" : "Добави папка",
    "Delete account" : "Изтриване на профила",
    "Show all folders" : "Покажи всички папки",
    "Collapse folders" : "Свиване на папки",
    "Mark all as read" : "Маркирай всички като прочетени",
    "Mark all messages of this folder as read" : "Маркирай всички съобщения в папката като прочетени",
    "Add subfolder" : "Добави подпапка",
    "Loading …" : "Зарежда …",
    "No message selected" : "Не е избрано съобщение",
    "Signature" : "Подпис",
    "A signature is added to the text of new messages and replies." : "Подписът се добавя в края на текста, на изходящите съобщения.",
    "Signature …" : "Подпис…",
    "Email: {email}" : "Имейл: {email}",
    "General" : "Общи",
    "Email address" : "Имейл адрес",
    "IMAP" : "IMAP",
    "User" : "Потребител",
    "Host" : "Хост",
    "Port" : "Порт",
    "SMTP" : "SMTP",
    "Account settings" : "Настройки на профила",
    "Mail server" : "Имейл сървър",
    "Compose new message" : "Създай ново съобщение",
    "Newer message" : "Следващо съобщение",
    "Older message" : "Предишно съобщение",
    "Toggle star" : "Означи със/Премахни звезда",
    "Toggle unread" : "Означи като (не)/прочетено",
    "Search" : "Търси",
    "Refresh" : "Опресняване",
    "Connect your mail account" : "Свързване към ваш имейл профил",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n ново съобщение \nот {from}","%n нови съобщения\nот {from}"],
    "Nextcloud Mail" : "Nextcloud Имейл",
    "Could not load {tag}{name}{endtag}" : "{tag}{name}{endtag} не може да бъде зареден",
    "There was a problem loading {tag}{name}{endtag}" : "Проблем при зареждане на {tag}{name}{endtag}",
    "Could not load the desired message" : "Желаното съобщение не може да бъде заредено",
    "Could not load the message" : "Съобщението не може да бъде заредено",
    "Error loading message" : "Грешка при зареждане съобщението",
    "Forwarding to %s" : "Препращане към %s",
    "Redirect" : "Пренасочване",
    "The link leads to %s" : "Връзката води до %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Ако не желаете да посетите страницата може да се върнете към <a href=\"%s\">Поща</a>.",
    "Continue to %s" : "Продължи към %s"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-mail-1.3.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/bg.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Поща",
    "Auto detect failed. Please use manual mode." : "Неуспешни автоматични настройки. Моля, използвай ръчен режим.",
    "Creating account failed: " : "Неуспешно създаване на профил:",
    "Auto" : "Автоматично",
    "Name" : "Име",
    "Mail Address" : "Имейл адрес",
    "Password" : "Парола",
    "Manual" : "Ръчно",
    "IMAP Settings" : "IMAP настройки",
    "IMAP Host" : "IMAP сървър",
    "IMAP Security" : "IMAP сигурност",
    "None" : "Няма",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP порт",
    "IMAP User" : "IMAP потребител",
    "IMAP Password" : "IMAP парола",
    "SMTP Settings" : "SMTP настройки",
    "SMTP Host" : "SMTP сървър",
    "SMTP Security" : "SMTP сигурност",
    "SMTP Port" : "SMTP порт",
    "SMTP User" : "SMTP потребител",
    "SMTP Password" : "SMTP парола",
    "Save" : "Запис",
    "Connect" : "Свържи",
    "Add mail account" : "Добавяне на профил",
    "Keyboard shortcuts" : "Бързи клавиши",
    "From" : "От",
    "Select account" : "Избери профил",
    "To" : "До",
    "Contact or email address …" : "Контакт или имейл адрес...",
    "Subject" : "Тема",
    "Subject …" : "Тема...",
    "Draft saved" : "Черновата записана",
    "Upload attachment" : "Качи прикачен файл/ове",
    "Add attachment from Files" : "Прикачи от \"Файлове\"",
    "Enable formatting" : "Форматиран текст",
    "Sending …" : "Изпращане...",
    "Go back" : "Назад",
    "Retry" : "Опитай отново",
    "Message sent!" : "Съобщението е изпратено!",
    "Send" : "Изпрати",
    "Uploading {percent}% …" : "Качване {percent}% …",
    "Choose a file to add as attachment" : "Избери файл за прикачване",
    "Plain text" : "Обикновен текст",
    "Rich text" : "Форматиран текст",
    "No messages in this folder" : "Няма съобщения",
    "Draft: " : "Чернова: ",
    "Favorite" : "Любима",
    "Mark read" : "Маркирай като прочетено",
    "Mark unread" : "Маркирай като непрочетено",
    "Delete" : "Изтриване",
    "Loading messages" : "Зареждане на съобщенията",
    "to" : "до",
    "cc" : "ЯК",
    "Reply" : "Отговори",
    "Forward" : "Напред",
    "Could not load your message" : "Вашето съобщение не може да бъде заредено",
    "Download attachment" : "Изтегли прикачените файлове",
    "Save to Files" : "Запази във Файлове",
    "Unnamed" : "Без име",
    "Choose a folder to store the attachment in" : "Избери папка, където да бъде запазен прикаченият файл",
    "New message" : "Ново съобщение",
    "Settings" : "Настройки",
    "Edit account" : "Редактиране на профила",
    "Add folder" : "Добави папка",
    "Delete account" : "Изтриване на профила",
    "Show all folders" : "Покажи всички папки",
    "Collapse folders" : "Свиване на папки",
    "Mark all as read" : "Маркирай всички като прочетени",
    "Mark all messages of this folder as read" : "Маркирай всички съобщения в папката като прочетени",
    "Add subfolder" : "Добави подпапка",
    "Loading …" : "Зарежда …",
    "No message selected" : "Не е избрано съобщение",
    "Signature" : "Подпис",
    "A signature is added to the text of new messages and replies." : "Подписът се добавя в края на текста, на изходящите съобщения.",
    "Signature …" : "Подпис…",
    "Email: {email}" : "Имейл: {email}",
    "General" : "Общи",
    "Email address" : "Имейл адрес",
    "IMAP" : "IMAP",
    "User" : "Потребител",
    "Host" : "Хост",
    "Port" : "Порт",
    "SMTP" : "SMTP",
    "Account settings" : "Настройки на профила",
    "Mail server" : "Имейл сървър",
    "Compose new message" : "Създай ново съобщение",
    "Newer message" : "Следващо съобщение",
    "Older message" : "Предишно съобщение",
    "Toggle star" : "Означи със/Премахни звезда",
    "Toggle unread" : "Означи като (не)/прочетено",
    "Search" : "Търси",
    "Refresh" : "Опресняване",
    "Connect your mail account" : "Свързване към ваш имейл профил",
    "All" : "Всички",
    "Archive" : "Архивиране",
    "Drafts" : "Чернови",
    "Favorites" : "Любими",
    "All inboxes" : "Всички",
    "Inbox" : "Входящи",
    "Junk" : "Спам",
    "Sent" : "Изпратени",
    "Trash" : "Кошче",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n ново съобщение \nот {from}","%n нови съобщения\nот {from}"],
    "Nextcloud Mail" : "Nextcloud Имейл",
    "Could not load {tag}{name}{endtag}" : "{tag}{name}{endtag} не може да бъде зареден",
    "There was a problem loading {tag}{name}{endtag}" : "Проблем при зареждане на {tag}{name}{endtag}",
    "Could not load the desired message" : "Желаното съобщение не може да бъде заредено",
    "Could not load the message" : "Съобщението не може да бъде заредено",
    "Error loading message" : "Грешка при зареждане съобщението",
    "Forwarding to %s" : "Препращане към %s",
    "Redirect" : "Пренасочване",
    "The link leads to %s" : "Връзката води до %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Ако не желаете да посетите страницата може да се върнете към <a href=\"%s\">Поща</a>.",
    "Continue to %s" : "Продължи към %s"
},
"nplurals=2; plural=(n != 1);");
